        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>50</strong> miembros: 21 <strong>control</strong><br>0,1,4,5,7,8,9,22,24,25,26,28,31,32,34,35,38,40,42,44,50';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 20 <br>2,3,10,11,15,17,18,19,20,21,23,29,30,36,37,39,45,47,48,49';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 10 <br>6,12,13,14,16,27,33,41,43,46';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>50</strong> miembros: 21 <strong>control</strong><br>0,1,4,5,7,8,9,22,24,25,26,28,31,32,34,35,38,40,42,44,50';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 20 <br>2,3,10,11,15,17,18,19,20,21,23,29,30,36,37,39,45,47,48,49';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 10 <br>6,12,13,14,16,27,33,41,43,46';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>50</strong> miembros: 21 <strong>control</strong><br>0,1,4,5,7,8,9,22,24,25,26,28,31,32,34,35,38,40,42,44,50';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 20 <br>2,3,10,11,15,17,18,19,20,21,23,29,30,36,37,39,45,47,48,49';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 10 <br>6,12,13,14,16,27,33,41,43,46';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>50</strong> miembros: 21 <strong>control</strong><br>0,1,4,5,7,8,9,22,24,25,26,28,31,32,34,35,38,40,42,44,50';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 20 <br>2,3,10,11,15,17,18,19,20,21,23,29,30,36,37,39,45,47,48,49';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 10 <br>6,12,13,14,16,27,33,41,43,46';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>50</strong> miembros: 21 <strong>control</strong><br>0,1,4,5,7,8,9,22,24,25,26,28,31,32,34,35,38,40,42,44,50';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 20 <br>2,3,10,11,15,17,18,19,20,21,23,29,30,36,37,39,45,47,48,49';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 10 <br>6,12,13,14,16,27,33,41,43,46';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>50</strong> miembros: 21 <strong>control</strong><br>0,1,4,5,7,8,9,22,24,25,26,28,31,32,34,35,38,40,42,44,50';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 20 <br>2,3,10,11,15,17,18,19,20,21,23,29,30,36,37,39,45,47,48,49';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260612 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 10 <br>6,12,13,14,16,27,33,41,43,46';}
}
